==> at-spi2-core-2.9.4.tar.xz: at-spi2-core-2.9.4/atspi/atspi-enum-types.h <==

/* Generated data (by glib-mkenums) */

#ifndef __ATSPI_ENUM_TYPES_H__
#define __ATSPI_ENUM_TYPES_H__

#include <glib-object.h>

G_BEGIN_DECLS

/* Enumerations from "atspi-constants.h" */

#define ATSPI_TYPE_LOCALE_TYPE	(atspi_locale_type_get_type())
GType atspi_locale_type_get_type	(void) G_GNUC_CONST;

#define ATSPI_TYPE_COORD_TYPE	(atspi_coord_type_get_type())
GType atspi_coord_type_get_type	(void) G_GNUC_CONST;

#define ATSPI_TYPE_COLLECTION_SORT_ORDER	(atspi_collection_sort_order_get_type())
GType atspi_collection_sort_order_get_type	(void) G_GNUC_CONST;

#define ATSPI_TYPE_COLLECTION_MATCH_TYPE	(atspi_collection_match_type_get_type())
GType atspi_collection_match_type_get_type	(void) G_GNUC_CONST;

#define ATSPI_TYPE_COLLECTION_TREE_TRAVERSAL_TYPE	(atspi_collection_tree_traversal_type_get_type())
GType atspi_collection_tree_traversal_type_get_type	(void) G_GNUC_CONST;

#define ATSPI_TYPE_COMPONENT_LAYER	(atspi_component_layer_get_type())
GType atspi_component_layer_get_type	(void) G_GNUC_CONST;

#define ATSPI_TYPE_TEXT_BOUNDARY_TYPE	(atspi_text_boundary_type_get_type())
GType atspi_text_boundary_type_get_type	(void) G_GNUC_CONST;

#define ATSPI_TYPE_TEXT_CLIP_TYPE	(atspi_text_clip_type_get_type())
GType atspi_text_clip_type_get_type	(void) G_GNUC_CONST;

#define ATSPI_TYPE_STATE_TYPE	(atspi_state_type_get_type())
GType atspi_state_type_get_type	(void) G_GNUC_CONST;

#define ATSPI_TYPE_KEY_EVENT_TYPE	(atspi_key_event_type_get_type())
GType atspi_key_event_type_get_type	(void) G_GNUC_CONST;

#define ATSPI_TYPE_EVENT_TYPE	(atspi_event_type_get_type())
GType atspi_event_type_get_type	(void) G_GNUC_CONST;

#define ATSPI_TYPE_KEY_SYNTH_TYPE	(atspi_key_synth_type_get_type())
GType atspi_key_synth_type_get_type	(void) G_GNUC_CONST;

#define ATSPI_TYPE_MODIFIER_TYPE	(atspi_modifier_type_get_type())
GType atspi_modifier_type_get_type	(void) G_GNUC_CONST;

#define ATSPI_TYPE_RELATION_TYPE	(atspi_relation_type_get_type())
GType atspi_relation_type_get_type	(void) G_GNUC_CONST;

#define ATSPI_TYPE_ROLE	(atspi_role_get_type())
GType atspi_role_get_type	(void) G_GNUC_CONST;

#define ATSPI_TYPE_CACHE	(atspi_cache_get_type())
GType atspi_cache_get_type	(void) G_GNUC_CONST;

/* Enumerations from "atspi-types.h" */

#define ATSPI_TYPE_KEY_LISTENER_SYNC_TYPE	(atspi_key_listener_sync_type_get_type())
GType atspi_key_listener_sync_type_get_type	(void) G_GNUC_CONST;

G_END_DECLS

#endif /* __ATSPI_ENUM_TYPES_H__ */

/* Generated data ends here */

==> at-spi2-core-2.25.91.tar.xz: at-spi2-core-2.25.91/atspi/atspi-enum-types.h <==

/* Generated data (by glib-mkenums) */

#ifndef __ATSPI_ENUM_TYPES_H__
#define __ATSPI_ENUM_TYPES_H__

#include <glib-object.h>

G_BEGIN_DECLS

/* Enumerations from "./atspi-constants.h" */

#define ATSPI_TYPE_LOCALE_TYPE	(atspi_locale_type_get_type())
GType atspi_locale_type_get_type	(void) G_GNUC_CONST;

#define ATSPI_TYPE_COORD_TYPE	(atspi_coord_type_get_type())
GType atspi_coord_type_get_type	(void) G_GNUC_CONST;

#define ATSPI_TYPE_COLLECTION_SORT_ORDER	(atspi_collection_sort_order_get_type())
GType atspi_collection_sort_order_get_type	(void) G_GNUC_CONST;

#define ATSPI_TYPE_COLLECTION_MATCH_TYPE	(atspi_collection_match_type_get_type())
GType atspi_collection_match_type_get_type	(void) G_GNUC_CONST;

#define ATSPI_TYPE_COLLECTION_TREE_TRAVERSAL_TYPE	(atspi_collection_tree_traversal_type_get_type())
GType atspi_collection_tree_traversal_type_get_type	(void) G_GNUC_CONST;

#define ATSPI_TYPE_COMPONENT_LAYER	(atspi_component_layer_get_type())
GType atspi_component_layer_get_type	(void) G_GNUC_CONST;

#define ATSPI_TYPE_TEXT_BOUNDARY_TYPE	(atspi_text_boundary_type_get_type())
GType atspi_text_boundary_type_get_type	(void) G_GNUC_CONST;

#define ATSPI_TYPE_TEXT_GRANULARITY	(atspi_text_granularity_get_type())
GType atspi_text_granularity_get_type	(void) G_GNUC_CONST;

#define ATSPI_TYPE_TEXT_CLIP_TYPE	(atspi_text_clip_type_get_type())
GType atspi_text_clip_type_get_type	(void) G_GNUC_CONST;

#define ATSPI_TYPE_STATE_TYPE	(atspi_state_type_get_type())
GType atspi_state_type_get_type	(void) G_GNUC_CONST;

#define ATSPI_TYPE_KEY_EVENT_TYPE	(atspi_key_event_type_get_type())
GType atspi_key_event_type_get_type	(void) G_GNUC_CONST;

#define ATSPI_TYPE_EVENT_TYPE	(atspi_event_type_get_type())
GType atspi_event_type_get_type	(void) G_GNUC_CONST;

#define ATSPI_TYPE_KEY_SYNTH_TYPE	(atspi_key_synth_type_get_type())
GType atspi_key_synth_type_get_type	(void) G_GNUC_CONST;

#define ATSPI_TYPE_MODIFIER_TYPE	(atspi_modifier_type_get_type())
GType atspi_modifier_type_get_type	(void) G_GNUC_CONST;

#define ATSPI_TYPE_RELATION_TYPE	(atspi_relation_type_get_type())
GType atspi_relation_type_get_type	(void) G_GNUC_CONST;

#define ATSPI_TYPE_ROLE	(atspi_role_get_type())
GType atspi_role_get_type	(void) G_GNUC_CONST;

#define ATSPI_TYPE_CACHE	(atspi_cache_get_type())
GType atspi_cache_get_type	(void) G_GNUC_CONST;

/* Enumerations from "./atspi-types.h" */

#define ATSPI_TYPE_KEY_LISTENER_SYNC_TYPE	(atspi_key_listener_sync_type_get_type())
GType atspi_key_listener_sync_type_get_type	(void) G_GNUC_CONST;

G_END_DECLS

#endif /* __ATSPI_ENUM_TYPES_H__ */

/* Generated data ends here */
